/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_GUITARCHORDEDITOR2_H_
#define _RG_GUITARCHORDEDITOR2_H_

#include <kdialogbase.h>

#include "Chord.h"
#include "ChordMap.h"

class TQComboBox;
class TQSpinBox;

namespace Rosegarden
{

class FingeringBox;


class GuitarChordEditorDialog : public KDialogBase
{
    TQ_OBJECT
  
    
public:
	GuitarChordEditorDialog(Guitar::Chord&, const Guitar::ChordMap& chordMap, TQWidget *parent=0);

protected slots:
    void slotStartFretChanged(int);
    virtual void slotOk();
    
protected:

    void populateExtensions(const TQStringList&);

    FingeringBox* m_fingeringBox;
    TQComboBox* m_rootNotesList;
    TQSpinBox* m_startFret;
    TQComboBox* m_ext;
    Guitar::Chord& m_chord;
    const Guitar::ChordMap& m_chordMap;    
};

}

#endif /*_RG_GUITARCHORDEDITOR2_H_*/
